@@ -17,4 +17,5 @@ class TreeNodeForm(forms.ModelForm):
             exclude_pks += [obj.pk]
             exclude_pks += split_pks(obj.tn_descendants_pks)
         manager = obj.__class__.objects
-        self.fields['tn_parent'].queryset = manager.exclude(pk__in=exclude_pks)
+        self.fields['tn_parent'].queryset = manager.prefetch_related(
+            'tn_children').exclude(pk__in=exclude_pks)
